# Suffixes and credentials to strip from names.
# Extracted from python-nameparser (MIT license) and supplemented.
# All entries are lowercase for case-insensitive matching.

SUFFIXES: set[str] = {
    # Generational
    "jr", "jr.", "junior",
    "sr", "sr.", "senior",
    "i", "ii", "iii", "iv", "v", "vi", "vii", "viii", "ix", "x",
    "1st", "2nd", "3rd", "4th", "5th",
    # Academic degrees
    "phd", "ph.d", "ph.d.",
    "md", "m.d", "m.d.",
    "do", "d.o", "d.o.",
    "dds", "d.d.s", "d.d.s.",
    "dmd", "d.m.d",
    "dvm", "d.v.m",
    "od", "o.d",
    "jd", "j.d", "j.d.",
    "llm", "ll.m",
    "llb", "ll.b",
    "sjd", "s.j.d",
    "edd", "ed.d",
    "dba", "d.b.a",
    "dmin", "d.min",
    "thd", "th.d",
    "psyd", "psy.d",
    "pharmd", "pharm.d",
    "dnp", "d.n.p",
    "dpt", "d.p.t",
    "dsc", "d.sc",
    "drph", "dr.ph",
    "engd", "eng.d",
    "ma", "m.a", "m.a.",
    "ms", "m.s", "m.s.",
    "msc", "m.sc",
    "mba", "m.b.a",
    "mpa", "m.p.a",
    "mph", "m.p.h",
    "mfa", "m.f.a",
    "msw", "m.s.w",
    "med", "m.ed",
    "meng", "m.eng",
    "mphil", "m.phil",
    "mth", "m.th",
    "mdiv", "m.div",
    "ba", "b.a", "b.a.",
    "bs", "b.s", "b.s.",
    "bsc", "b.sc",
    "bba", "b.b.a",
    "bfa", "b.f.a",
    "beng", "b.eng",
    "bed", "b.ed",
    "bmus", "b.mus",
    "aa", "a.a",
    "as", "a.s",
    "aas", "a.a.s",
    # Professional certifications
    "cpa", "c.p.a",
    "cfa", "c.f.a",
    "cfp", "c.f.p",
    "cfe", "c.f.e",
    "cia", "c.i.a",
    "cma", "c.m.a",
    "cisa", "c.i.s.a",
    "cism", "c.i.s.m",
    "cissp",
    "pmp",
    "pe", "p.e",
    "ra", "r.a",
    "aia", "a.i.a",
    "faia",
    "asla",
    "rn", "r.n",
    "bsn", "b.s.n",
    "msn", "m.s.n",
    "aprn", "a.p.r.n",
    "fnp", "f.n.p",
    "np", "n.p",
    "lpn", "l.p.n",
    "cna", "c.n.a",
    "crna", "c.r.n.a",
    "pa", "p.a",
    "pac", "pa-c",
    "pt", "p.t",
    "ot", "o.t",
    "slp",
    "rd", "r.d",
    "ldn", "l.d.n",
    "rdn",
    "lcsw", "l.c.s.w",
    "lmft", "l.m.f.t",
    "lpc", "l.p.c",
    "lmhc",
    "bcba",
    "nbct",
    # Legal
    "esq", "esquire",
    "jd",
    "llm",
    "qc", "q.c",
    "kc", "k.c",
    "sc", "s.c",
    # Religious
    "dd", "d.d",
    "thm", "th.m",
    "stm", "s.t.m",
    "std", "s.t.d",
    "osb", "op", "sj", "ofm", "ocso",
    # Military
    "ret", "retired",
    "usa", "usn", "usaf", "usmc", "uscg",
    # British / Commonwealth honors
    "obe", "o.b.e",
    "mbe", "m.b.e",
    "cbe", "c.b.e",
    "dbe", "d.b.e",
    "kbe", "k.b.e",
    "gbe", "g.b.e",
    "kcb", "gcb", "cb",
    "kcmg", "gcmg", "cmg",
    "kcvo", "gcvo", "cvo", "lvo", "mvo",
    "ch",
    "dso",
    "mc",
    "dfc",
    "afc",
    "gm",
    "qgm",
    "bpm",
    "qpm",
    "ksg",
    "kcsg",
    "gcsg",
    "kt",
    "kg",
    "kp",
    "gch",
    "bt",
    "pc",
    "mp",
    "msp", "mla", "am", "mep",
    "td",
    "vd",
    "cd",
    "jp",
    "dl",
    "frcp", "frcs", "frcgp", "frcog", "frcpath", "frcpch", "frcem",
    "frs", "fra", "frsa", "fba", "frei", "frgs",
    "fice", "fiet", "fimeche", "fistructe",
    "fcca", "fca", "fcma", "fcis", "fcii", "fcmi", "fcips",
    "fiod",
    # Fellowships / honorary
    "fellow",
    "facp", "facs", "facep", "faan", "faap", "faha",
    "facc", "facg", "facr", "fasco", "fasge",
    "fasn", "fccp", "fesc", "fhrs", "fnla",
    # Other
    "ret",
    "deceased",
    "aka",
}
